@@ -8,10 +8,9 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.aws_iam
-import aws_cdk.core
-
-__jsii_assembly__ = jsii.JSIIAssembly.load("iam-floyd", "0.23.0", __name__[0:-6], "iam-floyd@0.23.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "iam-floyd", "0.27.0", __name__[0:-6], "iam-floyd@0.27.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
